# LUME-Genesis
Genesis tools for use in LUME

<div align="center">
  <img src="assets/field.png", width="800">
</div>



---
# Related Publications

The lume-genesis package was used in the following publications:

*Very high brightness and power LCLS-II hard X-ray pulses*
Aliaksei Halavanau, Franz-Josef Decker, Claudio Emma, Jackson Sheppard, and Claudio Pellegrini,
J. Synchrotron Rad. (2019). 26
[[https://doi.org/10.1107/S1600577519002492](https://doi.org/10.1107/S1600577519002492)]
